@@ -3,7 +3,7 @@
 package Perinci::Examples;
 
 our $DATE = '2019-07-19'; # DATE
-our $VERSION = '0.817'; # VERSION
+our $VERSION = '0.818'; # VERSION
 
 use 5.010001;
 use strict;
@@ -455,6 +455,23 @@ _
                 ],
             }],
         },
+        s1c => {
+            summary => 'String with examples in schema',
+            schema  => [str => {
+                examples => [
+                    'bar',
+                    {value=>'baz', summary=>'foo'},
+                ],
+            }],
+        },
+        s1d => {
+            summary => 'String with examples in argument spec',
+            schema  => ['str'],
+            examples => [
+                'bar',
+                {value=>'baz', summary=>'foo'},
+            ],
+        },
         s2 => {
             summary => 'String with completion routine that generate random letter',
             schema  => 'str',
@@ -1133,7 +1150,7 @@ Perinci::Examples - Various examples of Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.817 of Perinci::Examples (from Perl distribution Perinci-Examples), released on 2019-07-19.
+This document describes version 0.818 of Perinci::Examples (from Perl distribution Perinci-Examples), released on 2019-07-19.
 
 =head1 DESCRIPTION
 
@@ -2226,6 +2243,14 @@ String with possible values in "in" schema clause, contains special characters.
 
 This argument is intended to test how special characters are escaped.
 
+=item * B<s1c> => I<str>
+
+String with examples in schema.
+
+=item * B<s1d> => I<str>
+
+String with examples in argument spec.
+
 =item * B<s2> => I<str>
 
 String with completion routine that generate random letter.
